@@ -39,7 +39,9 @@ from airflow.providers.openlineage.utils.utils import (
     get_airflow_job_facet,
     get_airflow_mapped_task_facet,
     get_airflow_run_facet,
+    get_dag_documentation,
     get_job_name,
+    get_task_documentation,
     get_task_parent_run_facet,
     get_user_provided_run_facets,
     is_operator_disabled,
@@ -103,11 +105,11 @@ class OpenLineageListener:
     else:
 
         @hookimpl
-        def on_task_instance_running(
+        def on_task_instance_running(  # type: ignore[misc]
             self,
             previous_state: TaskInstanceState,
             task_instance: TaskInstance,
-            session: Session,  # type: ignore[valid-type]
+            session: Session,
         ) -> None:
             from airflow.providers.openlineage.utils.utils import is_ti_rescheduled_already
 
@@ -192,6 +194,10 @@ class OpenLineageListener:
             if isinstance(data_interval_end, datetime):
                 data_interval_end = data_interval_end.isoformat()
 
+            doc, doc_type = get_task_documentation(task)
+            if not doc:
+                doc, doc_type = get_dag_documentation(dag)
+
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
                     dagrun=dagrun, task=task, task_instance_state=TaskInstanceState.RUNNING
@@ -200,7 +206,8 @@ class OpenLineageListener:
             redacted_event = self.adapter.start_task(
                 run_id=task_uuid,
                 job_name=get_job_name(task_instance),
-                job_description=dag.description,
+                job_description=doc,
+                job_description_type=doc_type,
                 event_time=start_date.isoformat(),
                 nominal_start_time=data_interval_start,
                 nominal_end_time=data_interval_end,
@@ -250,11 +257,11 @@ class OpenLineageListener:
     else:
 
         @hookimpl
-        def on_task_instance_success(
+        def on_task_instance_success(  # type: ignore[misc]
             self,
             previous_state: TaskInstanceState,
             task_instance: TaskInstance,
-            session: Session,  # type: ignore[valid-type]
+            session: Session,
         ) -> None:
             self.log.debug("OpenLineage listener got notification about task instance success")
             task = task_instance.task
@@ -311,6 +318,10 @@ class OpenLineageListener:
             if isinstance(data_interval_end, datetime):
                 data_interval_end = data_interval_end.isoformat()
 
+            doc, doc_type = get_task_documentation(task)
+            if not doc:
+                doc, doc_type = get_dag_documentation(dag)
+
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
                     dagrun=dagrun,
@@ -327,6 +338,8 @@ class OpenLineageListener:
                 # If task owner is default ("airflow"), use DAG owner instead that may have more details
                 owners=[x.strip() for x in (task if task.owner != "airflow" else dag).owner.split(",")],
                 tags=dag.tags,
+                job_description=doc,
+                job_description_type=doc_type,
                 nominal_start_time=data_interval_start,
                 nominal_end_time=data_interval_end,
                 run_facets={
@@ -373,12 +386,12 @@ class OpenLineageListener:
     else:
 
         @hookimpl
-        def on_task_instance_failed(
+        def on_task_instance_failed(  # type: ignore[misc]
             self,
             previous_state: TaskInstanceState,
             task_instance: TaskInstance,
             error: None | str | BaseException,
-            session: Session,  # type: ignore[valid-type]
+            session: Session,
         ) -> None:
             self.log.debug("OpenLineage listener got notification about task instance failure")
             task = task_instance.task
@@ -442,6 +455,10 @@ class OpenLineageListener:
             if isinstance(data_interval_end, datetime):
                 data_interval_end = data_interval_end.isoformat()
 
+            doc, doc_type = get_task_documentation(task)
+            if not doc:
+                doc, doc_type = get_dag_documentation(dag)
+
             with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
                 task_metadata = self.extractor_manager.extract_metadata(
                     dagrun=dagrun,
@@ -461,6 +478,8 @@ class OpenLineageListener:
                 tags=dag.tags,
                 # If task owner is default ("airflow"), use DAG owner instead that may have more details
                 owners=[x.strip() for x in (task if task.owner != "airflow" else dag).owner.split(",")],
+                job_description=doc,
+                job_description_type=doc_type,
                 run_facets={
                     **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=dag.dag_id),
                     **get_user_provided_run_facets(task_instance, TaskInstanceState.FAILED),
@@ -511,6 +530,8 @@ class OpenLineageListener:
                 "nominal_end_time": None,
                 "tags": None,
                 "owners": None,
+                "job_description": None,
+                "job_description_type": None,
                 "run_facets": {
                     **get_task_parent_run_facet(parent_run_id=parent_run_id, parent_job_name=ti.dag_id),
                     **get_airflow_debug_facet(),
@@ -623,6 +644,8 @@ class OpenLineageListener:
             if AIRFLOW_V_3_0_PLUS and date is None:
                 date = dag_run.run_after
 
+            doc, doc_type = get_dag_documentation(dag_run.dag)
+
             self.submit_callable(
                 self.adapter.dag_started,
                 dag_id=dag_run.dag_id,
@@ -633,7 +656,8 @@ class OpenLineageListener:
                 run_facets=run_facets,
                 clear_number=dag_run.clear_number,
                 owners=[x.strip() for x in dag_run.dag.owner.split(",")] if dag_run.dag else None,
-                description=dag_run.dag.description if dag_run.dag else None,
+                job_description=doc,
+                job_description_type=doc_type,
                 tags=dag_run.dag.tags if dag_run.dag else [],
                 # AirflowJobFacet should be created outside ProcessPoolExecutor that pickles objects,
                 # as it causes lack of some TaskGroup attributes and crashes event emission.
@@ -668,6 +692,7 @@ class OpenLineageListener:
                 dag_run.data_interval_start.isoformat() if dag_run.data_interval_start else None
             )
             data_interval_end = dag_run.data_interval_end.isoformat() if dag_run.data_interval_end else None
+            doc, doc_type = get_dag_documentation(dag_run.dag)
 
             self.submit_callable(
                 self.adapter.dag_success,
@@ -680,6 +705,8 @@ class OpenLineageListener:
                 clear_number=dag_run.clear_number,
                 owners=[x.strip() for x in dag_run.dag.owner.split(",")] if dag_run.dag else None,
                 tags=dag_run.dag.tags if dag_run.dag else [],
+                job_description=doc,
+                job_description_type=doc_type,
                 task_ids=task_ids,
                 dag_run_state=dag_run.get_state(),
                 run_facets={**get_airflow_dag_run_facet(dag_run)},
@@ -713,6 +740,7 @@ class OpenLineageListener:
                 dag_run.data_interval_start.isoformat() if dag_run.data_interval_start else None
             )
             data_interval_end = dag_run.data_interval_end.isoformat() if dag_run.data_interval_end else None
+            doc, doc_type = get_dag_documentation(dag_run.dag)
 
             self.submit_callable(
                 self.adapter.dag_failed,
@@ -725,6 +753,8 @@ class OpenLineageListener:
                 clear_number=dag_run.clear_number,
                 owners=[x.strip() for x in dag_run.dag.owner.split(",")] if dag_run.dag else None,
                 tags=dag_run.dag.tags if dag_run.dag else [],
+                job_description=doc,
+                job_description_type=doc_type,
                 dag_run_state=dag_run.get_state(),
                 task_ids=task_ids,
                 msg=msg,
