@@ -203,7 +203,10 @@ class TestOpenLineageListenerAirflow2:
             state=DagRunState.RUNNING,
             execution_date=date,  # type: ignore
         )
-        task_instance = TaskInstance(t, run_id=run_id)
+        if AIRFLOW_V_3_0_PLUS:
+            task_instance = TaskInstance(t, run_id=run_id, dag_version_id=dagrun.created_dag_version_id)
+        else:
+            task_instance = TaskInstance(t, run_id=run_id)  # type: ignore
         return dagrun, task_instance
 
     def _create_listener_and_task_instance(self) -> tuple[OpenLineageListener, TaskInstance]:
@@ -241,8 +244,10 @@ class TestOpenLineageListenerAirflow2:
         adapter.fail_task = mock.Mock()
         adapter.complete_task = mock.Mock()
         listener.adapter = adapter
-
-        task_instance = TaskInstance(task=mock.Mock())
+        if AIRFLOW_V_3_0_PLUS:
+            task_instance = TaskInstance(task=mock.Mock(), dag_version_id=mock.MagicMock())
+        else:
+            task_instance = TaskInstance(task=mock.Mock())  # type: ignore
         task_instance.dag_run = DagRun()
         task_instance.dag_run.run_id = "dag_run_run_id"
         task_instance.dag_run.data_interval_start = None
@@ -254,9 +259,15 @@ class TestOpenLineageListenerAirflow2:
         task_instance.task.dag = mock.Mock()
         task_instance.task.dag.dag_id = "dag_id"
         task_instance.task.dag.description = "Test DAG Description"
+        task_instance.task.dag.doc_md = None
         task_instance.task.dag.owner = "Test Owner"
         task_instance.task.dag.tags = ["tag1", "tag2"]
         task_instance.task.owner = "task_owner"
+        task_instance.task.doc = None
+        task_instance.task.doc_md = "Test TASK Description"
+        task_instance.task.doc_json = None
+        task_instance.task.doc_yaml = None
+        task_instance.task.doc_rst = None
         task_instance.task.inlets = []
         task_instance.task.outlets = []
         task_instance.dag_id = "dag_id"
@@ -315,7 +326,8 @@ class TestOpenLineageListenerAirflow2:
         listener.adapter.start_task.assert_called_once_with(
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             job_name="dag_id.task_id",
-            job_description="Test DAG Description",
+            job_description="Test TASK Description",
+            job_description_type="text/markdown",
             event_time="2023-01-01T13:01:01+00:00",
             nominal_start_time=None,
             nominal_end_time=None,
@@ -368,20 +380,55 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
-    @mock.patch("airflow.utils.timezone.utcnow", return_value=timezone.datetime(2023, 1, 3, 13, 1, 1))
-    def test_adapter_fail_task_is_called_with_proper_arguments(
+    def test_adapter_start_task_is_called_with_dag_description_when_task_doc_is_empty(
         self,
-        mock_utcnow,
+        mock_get_job_name,
+        mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_facet,
         mock_debug_mode,
+    ):
+        listener, task_instance = self._create_listener_and_task_instance()
+        mock_get_job_name.return_value = "job_name"
+        mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
+        mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
+        mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
+        mock_debug_facet.return_value = {"debug": "packages"}
+        mock_disabled.return_value = False
+
+        task_instance.task.doc_md = None  # Simulate lack of task doc to force fallback to DAG description
+        listener.on_task_instance_running(None, task_instance, None)
+        assert listener.adapter.start_task.call_args.kwargs["job_description"] == "Test DAG Description"
+        assert listener.adapter.start_task.call_args.kwargs["job_description_type"] == "text/plain"
+
+    @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch(
+        "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
+    )
+    def test_adapter_fail_task_is_called_with_proper_arguments(
+        self,
+        mock_get_user_provided_run_facets,
+        mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
+        mock_disabled,
+        mock_debug_facet,
+        mock_debug_mode,
+        time_machine,
     ):
         """Tests that the 'fail_task' method of the OpenLineageAdapter is invoked with the correct arguments.
 
@@ -390,6 +437,7 @@ class TestOpenLineageListenerAirflow2:
         the test verifies the integrity and consistency of the data passed to the adapter during task
         failure events, thus confirming that the adapter's failure handling is functioning as expected.
         """
+        time_machine.move_to(timezone.datetime(2023, 1, 3, 13, 1, 1))
 
         listener, task_instance = self._create_listener_and_task_instance()
         task_instance.logical_date = timezone.datetime(2020, 1, 1, 1, 1, 1)
@@ -411,6 +459,8 @@ class TestOpenLineageListenerAirflow2:
             tags=["tag1", "tag2"],
             nominal_start_time=None,
             nominal_end_time=None,
+            job_description="Test TASK Description",
+            job_description_type="text/markdown",
             task=listener.extractor_manager.extract_metadata(),
             run_facets={
                 "parent": 4,
@@ -461,20 +511,55 @@ class TestOpenLineageListenerAirflow2:
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
-    @mock.patch("airflow.utils.timezone.utcnow", return_value=timezone.datetime(2023, 1, 3, 13, 1, 1))
-    def test_adapter_complete_task_is_called_with_proper_arguments(
+    def test_adapter_fail_task_is_called_with_dag_description_when_task_doc_is_empty(
         self,
-        mock_utcnow,
+        mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_facet,
         mock_debug_mode,
+    ):
+        listener, task_instance = self._create_listener_and_task_instance()
+        mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
+        mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
+        mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
+        mock_debug_facet.return_value = {"debug": "packages"}
+        mock_disabled.return_value = False
+
+        task_instance.task.doc_md = None  # Simulate lack of task doc to force fallback to DAG description
+        err = ValueError("test")
+        listener.on_task_instance_failed(
+            previous_state=None, task_instance=task_instance, error=err, session=None
+        )
+        assert listener.adapter.fail_task.call_args.kwargs["job_description"] == "Test DAG Description"
+        assert listener.adapter.fail_task.call_args.kwargs["job_description_type"] == "text/plain"
+
+    @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch(
+        "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
+    )
+    def test_adapter_complete_task_is_called_with_proper_arguments(
+        self,
+        mock_get_user_provided_run_facets,
+        mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
+        mock_disabled,
+        mock_debug_facet,
+        mock_debug_mode,
+        time_machine,
     ):
         """Tests that the 'complete_task' method of the OpenLineageAdapter is called with the correct arguments.
 
@@ -484,6 +569,7 @@ class TestOpenLineageListenerAirflow2:
         accordingly. This helps confirm the consistency and correctness of the data passed to the adapter
         during the task's lifecycle events.
         """
+        time_machine.move_to(timezone.datetime(2023, 1, 3, 13, 1, 1))
 
         listener, task_instance = self._create_listener_and_task_instance()
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
@@ -506,6 +592,8 @@ class TestOpenLineageListenerAirflow2:
             tags=["tag1", "tag2"],
             nominal_start_time=None,
             nominal_end_time=None,
+            job_description="Test TASK Description",
+            job_description_type="text/markdown",
             run_facets={
                 "parent": 4,
                 "custom_user_facet": 2,
@@ -546,6 +634,39 @@ class TestOpenLineageListenerAirflow2:
         listener.on_task_instance_success(None, task_instance, None)
         assert listener.adapter.complete_task.call_args.kwargs["owners"] == ["Test Owner"]
 
+    @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch(
+        "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
+    )
+    def test_adapter_complete_task_is_called_with_dag_description_when_task_doc_is_empty(
+        self,
+        mock_get_airflow_mapped_task_facet,
+        mock_get_user_provided_run_facets,
+        mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
+        mock_disabled,
+        mock_debug_facet,
+        mock_debug_mode,
+    ):
+        listener, task_instance = self._create_listener_and_task_instance()
+        mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
+        mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
+        mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
+        mock_debug_facet.return_value = {"debug": "packages"}
+        mock_disabled.return_value = False
+
+        task_instance.task.doc_md = None  # Simulate lack of task doc to force fallback to DAG description
+        listener.on_task_instance_success(None, task_instance, None)
+        assert listener.adapter.complete_task.call_args.kwargs["job_description"] == "Test DAG Description"
+        assert listener.adapter.complete_task.call_args.kwargs["job_description_type"] == "text/plain"
+
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
@@ -841,6 +962,7 @@ class TestOpenLineageListenerAirflow3:
             run_id=run_id,
             try_number=1,
             map_index=-1,
+            dag_version_id=uuid7(),
         )
 
         runtime_ti = RuntimeTaskInstance.model_construct(**ti.model_dump(exclude_unset=True), task=task)
@@ -926,9 +1048,9 @@ class TestOpenLineageListenerAirflow3:
             start_date=date,
             run_type=types.DagRunType.MANUAL,
             state=DagRunState.QUEUED,
-            **dagrun_kwargs,  # type: ignore
+            **dagrun_kwargs,
         )
-        task_instance = TaskInstance(t, run_id=run_id)
+        task_instance = TaskInstance(t, run_id=run_id)  # type: ignore
         task_instance.dag_run = dagrun
         return dagrun, task_instance
 
@@ -952,13 +1074,14 @@ class TestOpenLineageListenerAirflow3:
 
         if not runtime_ti:
             # TaskInstance is used when on API server (when listener gets called about manual state change)
-            task_instance = TaskInstance(task=MagicMock())  # type: ignore
+            task_instance = TaskInstance(task=MagicMock(), dag_version_id=uuid7())
             task_instance.dag_run = DagRun()
             task_instance.dag_run.dag_id = "dag_id_from_dagrun_and_not_ti"
             task_instance.dag_run.run_id = "dag_run_run_id"
             task_instance.dag_run.clear_number = 0
             task_instance.dag_run.logical_date = timezone.datetime(2020, 1, 1, 1, 1, 1)
             task_instance.dag_run.run_after = timezone.datetime(2020, 1, 1, 1, 1, 1)
+            task_instance.dag_run.state = DagRunState.RUNNING
             task_instance.task = None
             task_instance.dag = None
             task_instance.task_id = "task_id"
@@ -969,6 +1092,7 @@ class TestOpenLineageListenerAirflow3:
             # RuntimeTaskInstance is used when on worker
             from airflow.sdk.api.datamodels._generated import (
                 DagRun as SdkDagRun,
+                DagRunState as SdkDagRunState,
                 DagRunType,
                 TaskInstance as SdkTaskInstance,
                 TIRunContext,
@@ -981,7 +1105,9 @@ class TestOpenLineageListenerAirflow3:
                 description="Test DAG Description",
                 tags=["tag1", "tag2"],
             )
-            task = EmptyOperator(task_id="task_id_from_task_not_ti", dag=dag, owner="task_owner")
+            task = EmptyOperator(
+                task_id="task_id_from_task_not_ti", dag=dag, owner="task_owner", doc_md="TASK Description"
+            )
             task2 = EmptyOperator(task_id="task_id2_from_task_not_ti", dag=dag, owner="another_owner")  # noqa: F841
 
             sdk_task_instance = SdkTaskInstance(
@@ -991,24 +1117,26 @@ class TestOpenLineageListenerAirflow3:
                 run_id="dag_run_run_id",
                 try_number=1,
                 map_index=-1,
+                dag_version_id=uuid7(),
             )
             task_instance = RuntimeTaskInstance.model_construct(  # type: ignore
                 **sdk_task_instance.model_dump(exclude_unset=True),
                 task=task,
                 _ti_context_from_server=TIRunContext(
-                    dag_run=SdkDagRun(
-                        dag_id="dag_id_from_dagrun_not_ti",
-                        run_id="dag_run_run_id_from_dagrun_not_ti",
-                        logical_date=timezone.datetime(2020, 1, 1, 1, 1, 1),
-                        data_interval_start=None,
-                        data_interval_end=None,
-                        start_date=timezone.datetime(2023, 1, 1, 13, 1, 1),
-                        end_date=timezone.datetime(2023, 1, 3, 13, 1, 1),
-                        clear_number=0,
-                        run_type=DagRunType.MANUAL,
-                        run_after=timezone.datetime(2023, 1, 3, 13, 1, 1),
-                        conf=None,
-                        consumed_asset_events=[],
+                    dag_run=SdkDagRun.model_validate(
+                        {
+                            "dag_id": "dag_id_from_dagrun_not_ti",
+                            "run_id": "dag_run_run_id_from_dagrun_not_ti",
+                            "logical_date": timezone.datetime(2020, 1, 1, 1, 1, 1),
+                            "start_date": timezone.datetime(2023, 1, 1, 13, 1, 1),
+                            "end_date": timezone.datetime(2023, 1, 3, 13, 1, 1),
+                            "run_type": DagRunType.MANUAL,
+                            "run_after": timezone.datetime(2023, 1, 3, 13, 1, 1),
+                            "consumed_asset_events": [],
+                            **(
+                                {"state": SdkDagRunState.RUNNING} if "state" in SdkDagRun.model_fields else {}
+                            ),
+                        }
                     ),
                     task_reschedule_count=0,
                     max_tries=1,
@@ -1081,7 +1209,8 @@ class TestOpenLineageListenerAirflow3:
         listener.adapter.start_task.assert_called_once_with(
             run_id="2020-01-01T01:01:01+00:00.dag_id.task_id.1.-1",
             job_name="dag_id.task_id",
-            job_description="Test DAG Description",
+            job_description="TASK Description",
+            job_description_type="text/markdown",
             event_time="2023-01-01T13:01:01+00:00",
             nominal_start_time=None,
             nominal_end_time=None,
@@ -1135,20 +1264,55 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_job_name")
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
-    @mock.patch("airflow.utils.timezone.utcnow", return_value=timezone.datetime(2023, 1, 3, 13, 1, 1))
-    def test_adapter_fail_task_is_called_with_proper_arguments(
+    def test_adapter_start_task_is_called_with_dag_description_when_task_doc_is_empty(
         self,
-        mock_utcnow,
+        mock_get_job_name,
+        mock_get_airflow_mapped_task_facet,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_facet,
         mock_debug_mode,
+    ):
+        listener, task_instance = self._create_listener_and_task_instance()
+        mock_get_job_name.return_value = "job_name"
+        mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
+        mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
+        mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
+        mock_debug_facet.return_value = {"debug": "packages"}
+        mock_disabled.return_value = False
+
+        task_instance.task.doc_md = None  # Simulate lack of task doc to force fallback to DAG description
+        listener.on_task_instance_running(None, task_instance)
+        assert listener.adapter.start_task.call_args.kwargs["job_description"] == "Test DAG Description"
+        assert listener.adapter.start_task.call_args.kwargs["job_description_type"] == "text/plain"
+
+    @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch(
+        "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
+    )
+    def test_adapter_fail_task_is_called_with_proper_arguments(
+        self,
+        mock_get_user_provided_run_facets,
+        mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
+        mock_disabled,
+        mock_debug_facet,
+        mock_debug_mode,
+        time_machine,
     ):
         """Tests that the 'fail_task' method of the OpenLineageAdapter is invoked with the correct arguments.
 
@@ -1157,6 +1321,7 @@ class TestOpenLineageListenerAirflow3:
         the test verifies the integrity and consistency of the data passed to the adapter during task
         failure events, thus confirming that the adapter's failure handling is functioning as expected.
         """
+        time_machine.move_to(timezone.datetime(2023, 1, 3, 13, 1, 1), tick=False)
 
         listener, task_instance = self._create_listener_and_task_instance()
         task_instance.get_template_context()["dag_run"].logical_date = timezone.datetime(2020, 1, 1, 1, 1, 1)
@@ -1175,6 +1340,8 @@ class TestOpenLineageListenerAirflow3:
             task=listener.extractor_manager.extract_metadata(),
             owners=["task_owner"],
             tags={"tag1", "tag2"},
+            job_description="TASK Description",
+            job_description_type="text/markdown",
             nominal_start_time=None,
             nominal_end_time=None,
             run_facets={
@@ -1221,6 +1388,40 @@ class TestOpenLineageListenerAirflow3:
         call_owners = listener.adapter.fail_task.call_args.kwargs["owners"]
         assert sorted(call_owners) == ["airflow", "another_owner"]
 
+    @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch(
+        "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
+    )
+    def test_adapter_fail_task_is_called_with_dag_description_when_task_doc_is_empty(
+        self,
+        mock_get_airflow_mapped_task_facet,
+        mock_get_user_provided_run_facets,
+        mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
+        mock_disabled,
+        mock_debug_facet,
+        mock_debug_mode,
+    ):
+        listener, task_instance = self._create_listener_and_task_instance()
+        mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
+        mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
+        mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
+        mock_debug_facet.return_value = {"debug": "packages"}
+        mock_disabled.return_value = False
+
+        task_instance.task.doc_md = None  # Simulate lack of task doc to force fallback to DAG description
+        err = ValueError("test")
+        listener.on_task_instance_failed(previous_state=None, task_instance=task_instance, error=err)
+        assert listener.adapter.fail_task.call_args.kwargs["job_description"] == "Test DAG Description"
+        assert listener.adapter.fail_task.call_args.kwargs["job_description_type"] == "text/plain"
+
     @mock.patch("airflow.providers.openlineage.plugins.adapter.OpenLineageAdapter.emit")
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
@@ -1228,20 +1429,20 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
-    @mock.patch("airflow.utils.timezone.utcnow", return_value=timezone.datetime(2023, 1, 3, 13, 1, 1))
     def test_adapter_fail_task_is_called_with_proper_arguments_for_db_task_instance_model(
         self,
-        mock_utcnow,
         mock_get_task_parent_run_facet,
         mock_debug_facet,
         mock_debug_mode,
         mock_emit,
+        time_machine,
     ):
         """Tests that the 'fail_task' method of the OpenLineageAdapter is invoked with the correct arguments.
 
         This particular test is using TaskInstance model available on API Server and not on worker,
         to simulate the listener being called after task's state has been manually set via API.
         """
+        time_machine.move_to(timezone.datetime(2023, 1, 3, 13, 1, 1), tick=False)
 
         listener, task_instance = self._create_listener_and_task_instance(runtime_ti=False)
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
@@ -1262,6 +1463,8 @@ class TestOpenLineageListenerAirflow3:
             nominal_end_time=None,
             tags=None,
             owners=None,
+            job_description=None,
+            job_description_type=None,
             run_facets={
                 "parent": 4,
                 "debug": "packages",
@@ -1284,16 +1487,15 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
-    @mock.patch("airflow.utils.timezone.utcnow", return_value=timezone.datetime(2023, 1, 3, 13, 1, 1))
     def test_adapter_complete_task_is_called_with_proper_arguments(
         self,
-        mock_utcnow,
         mock_get_user_provided_run_facets,
         mock_get_airflow_run_facet,
         mock_get_task_parent_run_facet,
         mock_disabled,
         mock_debug_facet,
         mock_debug_mode,
+        time_machine,
     ):
         """Tests that the 'complete_task' method of the OpenLineageAdapter is called with the correct arguments.
 
@@ -1303,6 +1505,7 @@ class TestOpenLineageListenerAirflow3:
         accordingly. This helps confirm the consistency and correctness of the data passed to the adapter
         during the task's lifecycle events.
         """
+        time_machine.move_to(timezone.datetime(2023, 1, 3, 13, 1, 1), tick=False)
 
         listener, task_instance = self._create_listener_and_task_instance()
         mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
@@ -1321,6 +1524,8 @@ class TestOpenLineageListenerAirflow3:
             task=listener.extractor_manager.extract_metadata(),
             owners=["task_owner"],
             tags={"tag1", "tag2"},
+            job_description="TASK Description",
+            job_description_type="text/markdown",
             nominal_start_time=None,
             nominal_end_time=None,
             run_facets={
@@ -1365,6 +1570,39 @@ class TestOpenLineageListenerAirflow3:
         call_owners = listener.adapter.complete_task.call_args.kwargs["owners"]
         assert sorted(call_owners) == ["airflow", "another_owner"]
 
+    @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.is_operator_disabled")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_task_parent_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_run_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_mapped_task_facet")
+    @mock.patch("airflow.providers.openlineage.plugins.listener.get_user_provided_run_facets")
+    @mock.patch(
+        "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
+    )
+    def test_adapter_complete_task_is_called_with_dag_description_when_task_doc_is_empty(
+        self,
+        mock_get_airflow_mapped_task_facet,
+        mock_get_user_provided_run_facets,
+        mock_get_airflow_run_facet,
+        mock_get_task_parent_run_facet,
+        mock_disabled,
+        mock_debug_facet,
+        mock_debug_mode,
+    ):
+        listener, task_instance = self._create_listener_and_task_instance()
+        mock_get_airflow_mapped_task_facet.return_value = {"mapped_facet": 1}
+        mock_get_user_provided_run_facets.return_value = {"custom_user_facet": 2}
+        mock_get_airflow_run_facet.return_value = {"airflow_run_facet": 3}
+        mock_get_task_parent_run_facet.return_value = {"parent": 4}
+        mock_debug_facet.return_value = {"debug": "packages"}
+        mock_disabled.return_value = False
+
+        task_instance.task.doc_md = None  # Simulate lack of task doc to force fallback to DAG description
+        listener.on_task_instance_success(None, task_instance)
+        assert listener.adapter.complete_task.call_args.kwargs["job_description"] == "Test DAG Description"
+        assert listener.adapter.complete_task.call_args.kwargs["job_description_type"] == "text/plain"
+
     @mock.patch("airflow.providers.openlineage.plugins.adapter.OpenLineageAdapter.emit")
     @mock.patch("airflow.providers.openlineage.conf.debug_mode", return_value=True)
     @mock.patch("airflow.providers.openlineage.plugins.listener.get_airflow_debug_facet")
@@ -1372,15 +1610,16 @@ class TestOpenLineageListenerAirflow3:
     @mock.patch(
         "airflow.providers.openlineage.plugins.listener.OpenLineageListener._execute", new=regular_call
     )
-    @mock.patch("airflow.utils.timezone.utcnow", return_value=timezone.datetime(2023, 1, 3, 13, 1, 1))
     def test_adapter_complete_task_is_called_with_proper_arguments_for_db_task_instance_model(
-        self, mock_utcnow, mock_get_task_parent_run_facet, mock_debug_facet, mock_debug_mode, mock_emit
+        self, mock_get_task_parent_run_facet, mock_debug_facet, mock_debug_mode, mock_emit, time_machine
     ):
         """Tests that the 'complete_task' method of the OpenLineageAdapter is called with the correct arguments.
 
         This particular test is using TaskInstance model available on API Server and not on worker,
         to simulate the listener being called after task's state has been manually set via API.
         """
+        time_machine.move_to(timezone.datetime(2023, 1, 3, 13, 1, 1), tick=False)
+
         listener, task_instance = self._create_listener_and_task_instance(runtime_ti=False)
         mock_get_task_parent_run_facet.return_value = {"parent": 4}
         mock_debug_facet.return_value = {"debug": "packages"}
@@ -1400,6 +1639,8 @@ class TestOpenLineageListenerAirflow3:
             nominal_end_time=None,
             tags=None,
             owners=None,
+            job_description=None,
+            job_description_type=None,
             run_facets={
                 "parent": 4,
                 "debug": "packages",
@@ -1630,7 +1871,7 @@ class TestOpenLineageSelectiveEnableAirflow2:
             run_type=types.DagRunType.MANUAL,
             state=DagRunState.QUEUED,
             execution_date=date,
-        )  # type: ignore
+        )
         self.task_instance_1 = TaskInstance(self.task_1, run_id=run_id, map_index=-1)
         self.task_instance_2 = TaskInstance(self.task_2, run_id=run_id, map_index=-1)
         self.task_instance_1.dag_run = self.task_instance_2.dag_run = self.dagrun
